@@ -656,6 +656,19 @@ impl FromByteSlice for [bool; 480] {
     fn bytes_expected() -> usize { 60 }
 }
 
+impl ToBytes for [u8; 2] {
+    fn to_le_byte_vec(arr: [u8; 2]) -> Vec<u8> { arr.to_vec() }
+}
+
+impl FromByteSlice for [u8; 2] {
+    fn from_le_byte_slice(bytes: &[u8]) -> [u8; 2] {
+        let mut buf = [0u8; 2];
+        buf.copy_from_slice(bytes);
+        buf
+    }
+    fn bytes_expected() -> usize { 2 }
+}
+
 impl ToBytes for [u8; 3] {
     fn to_le_byte_vec(arr: [u8; 3]) -> Vec<u8> { arr.to_vec() }
 }
@@ -773,6 +786,19 @@ impl FromByteSlice for [u8; 16] {
     fn bytes_expected() -> usize { 16 }
 }
 
+impl ToBytes for [u8; 20] {
+    fn to_le_byte_vec(arr: [u8; 20]) -> Vec<u8> { arr.to_vec() }
+}
+
+impl FromByteSlice for [u8; 20] {
+    fn from_le_byte_slice(bytes: &[u8]) -> [u8; 20] {
+        let mut buf = [0u8; 20];
+        buf.copy_from_slice(bytes);
+        buf
+    }
+    fn bytes_expected() -> usize { 20 }
+}
+
 impl ToBytes for [u8; 32] {
     fn to_le_byte_vec(arr: [u8; 32]) -> Vec<u8> { arr.to_vec() }
 }
@@ -2163,6 +2189,23 @@ impl FromByteSlice for [u16; 10] {
     fn bytes_expected() -> usize { 20 }
 }
 
+impl ToBytes for [u16; 20] {
+    fn to_le_byte_vec(arr: [u16; 20]) -> Vec<u8> {
+        let mut buf = vec![0, 40];
+        LittleEndian::write_u16_into(&arr, &mut buf);
+        buf
+    }
+}
+
+impl FromByteSlice for [u16; 20] {
+    fn from_le_byte_slice(bytes: &[u8]) -> [u16; 20] {
+        let mut buf = [0u16; 20];
+        LittleEndian::read_u16_into(&bytes, &mut buf);
+        buf
+    }
+    fn bytes_expected() -> usize { 40 }
+}
+
 impl ToBytes for [u16; 27] {
     fn to_le_byte_vec(arr: [u16; 27]) -> Vec<u8> {
         let mut buf = vec![0, 54];
